==> haskell-lens-action-0.2.6-322.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-1XvV3zxhbTn1tw5LDO1JrA
key:                  lens-action-0.2.6-1XvV3zxhbTn1tw5LDO1JrA
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  aa9410ce129e8fa89c93215185f01632
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-1XvV3zxhbTn1tw5LDO1JrA
depends:
    base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM mtl-2.3.1
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-action-0.2.6-323-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-JckjjvCe2xp8jE09bEepRo
key:                  lens-action-0.2.6-JckjjvCe2xp8jE09bEepRo
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  5d3809d9f9531ac4350b147e26e8017a
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-JckjjvCe2xp8jE09bEepRo
depends:
    base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB mtl-2.3.1
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
